@@ -6,6 +6,7 @@ from typing import Final
 class BFn:
     array_agg: Final[str] = 'array_agg'
     array_append: Final[str] = 'array_append'
+    array_cat: Final[str] = 'array_cat'
     array_length: Final[str] = 'array_length'
     array_position: Final[str] = 'array_position'
     array_to_json: Final[str] = 'array_to_json'
@@ -20,6 +21,7 @@ class BFn:
     current_timestamp: Final[str] = 'current_timestamp'
 
     decode: Final[str] = 'decode'
+    digest: Final[str] = 'digest'
 
     encode: Final[str] = 'encode'
     enum_range: Final[str] = 'enum_range'
@@ -65,8 +67,10 @@ class BFn:
     sum: Final[str] = 'sum'
 
     to_jsonb: Final[str] = 'to_jsonb'
+    translate: Final[str] = 'translate'
     trim: Final[str] = 'trim'
 
+    unnest: Final[str] = 'unnest'
     uniq: Final[str] = 'uniq'
     uuid_generate_v4: Final[str] = 'uuid_generate_v4'
 
