@@ -4,8 +4,8 @@ from typing import Final
 class FnT:  # Function Arg Types
     BIGINT: Final[str] = 'BIGINT'
     BIGINT_ARRAY : Final[str]= 'BIGINT[]'
-
     BOOLEAN: Final[str] = 'BOOLEAN'
+    BYTEA: Final[str] = 'BYTEA'
     
     FLOAT: Final[str] = 'FLOAT'
 
@@ -15,6 +15,8 @@ class FnT:  # Function Arg Types
     JSONB: Final[str] = 'JSONB'
     JSONB_ARRAY: Final[str] = 'JSONB[]'
 
+    RECORD: Final[str] = 'RECORD'
+
     SMALLINT: Final[str] = 'SMALLINT'
     SMALLINT_ARRAY: Final[str] = 'SMALLINT[]'
 
