@@ -1,5 +1,6 @@
 
 from volworld_common.api.CA import CA
+
 from volsite_postgres_common.db.BFn import BFn
 from volsite_postgres_common.db.CFn import CFn
 from volsite_postgres_common.fn.function import Arg
@@ -71,8 +72,20 @@ class SQL:
     def input_2_uuid(att: str) -> str:
         return f"({Arg.input}->>'{att}')::UUID"
 
+    @staticmethod
+    def input_2_bigint(att: str) -> str:
+        return f"({Arg.input}->>'{att}')::BIGINT"
+
+    @staticmethod
+    def input_2_int(att: str) -> str:
+        return f"({Arg.input}->>'{att}')::INT"
+
     @staticmethod
     def input_iid_2_bint(att: str) -> str:
+        return SQL.input_iid_2_bigint(att)
+
+    @staticmethod
+    def input_iid_2_bigint(att: str) -> str:
         return f"{CFn.id_2_bigint}( ({Arg.input}->>'{att}')::TEXT )"
 
     @staticmethod
