@@ -81,17 +81,6 @@ jsonb_id_array_2_int_array: Final = (
     f" IMMUTABLE;")
 
 
-jsonb_uuid_array_2_uuid_array: Final = (
-    f" CREATE OR REPLACE FUNCTION "
-    f" {CFn.jsonb_uuid_array_2_uuid_array} (JSONB) "
-    f" RETURNS UUID[] "
-    f" AS $$ "
-    f"   SELECT array_agg((x))::UUID[] || ARRAY[]::UUID[] "
-    f"      FROM {BFn.jsonb_array_elements_text}($1) t(x);"
-    f" $$ "
-    f" LANGUAGE SQL "
-    f" IMMUTABLE;")
-
 bigint_array_2_id_array: Final = (
     f" CREATE OR REPLACE FUNCTION "
     f" {CFn.bigint_array_2_id_array} ("
@@ -110,7 +99,7 @@ bigint_array_2_id_array: Final = (
     f""
     f" FOREACH _text_id IN ARRAY _input "
     f" LOOP "
-    f"   _result := _result || bigint_2_id(_text_id); "
+    f"   _result := _result || {CFn.bigint_2_id}(_text_id); "
     f" END LOOP;"
     f""
     f" END;"
@@ -128,4 +117,3 @@ def insert_util_fn__id(conn):
 
     insert_function(jsonb_id_array_2_bigint_array, CFn.jsonb_id_array_2_bigint_array, conn)
     insert_function(jsonb_id_array_2_int_array, CFn.jsonb_id_array_2_int_array, conn)
-    insert_function(jsonb_uuid_array_2_uuid_array, CFn.jsonb_uuid_array_2_uuid_array, conn)
