@@ -4,11 +4,12 @@ from volworld_common.test.behave.BehaveUtil import BehaveUtil
 class UserInfo:
     def __init__(self, name: str, password: str = None):
         name = BehaveUtil.clear_string(name)
-        self.name = name
+        self.name: str = name
         # for testing wrong formatted username, put the name before generated id
-        self.used_name = f"{self.name}xxxxxx{new_rand_test_user_name()}"
-        self.password = password
-        self.user_id = rand_uuid()
+        self.used_name: str = f"{self.name}xxxxxx{new_rand_test_user_name()}"
+        self.password: str = password
+        self.user_uuid: str = rand_uuid()
+        self.user_id: int | None = None
 
 
 class UserPool:
